@@ -4,3 +4,10 @@ subprocess.check_output("/some_command",
                         "args",
                         shell=True,
                         universal_newlines=True)
+
+subprocess.check_output(
+    "/some_command",
+    "args",
+    shell=True,
+    universal_newlines=True
+)
